aboutsummaryrefslogtreecommitdiffstats
path: root/yage/yage.h
diff options
context:
space:
mode:
authorYann Herklotz <ymherklotz@gmail.com>2017-09-22 00:02:59 +0100
committerYann Herklotz <ymherklotz@gmail.com>2017-09-22 00:02:59 +0100
commit5deb18b72a4993a4baf59b7da24a04116eab31e6 (patch)
treec7a1523bed9bf7629b311d63e212957a6ae735be /yage/yage.h
parent34396f0483d94229e3a315e5eeb90c77c1425273 (diff)
parente8208166c67e564fb249aa41e9f8c5e2fa1f2b9a (diff)
downloadYAGE-5deb18b72a4993a4baf59b7da24a04116eab31e6.tar.gz
YAGE-5deb18b72a4993a4baf59b7da24a04116eab31e6.zip
Merge branch 'develop'
Diffstat (limited to 'yage/yage.h')
-rw-r--r--yage/yage.h25
1 files changed, 8 insertions, 17 deletions
diff --git a/yage/yage.h b/yage/yage.h
index 286d4784..4fce87dc 100644
--- a/yage/yage.h
+++ b/yage/yage.h
@@ -26,15 +26,10 @@
#include "base/vertex.h"
#include "base/window.h"
+#include "physics/body.h"
+#include "physics/particlebody.h"
#include "physics/rectanglecollider.h"
#include "physics/rigidbody.h"
-#include "physics/particlebody.h"
-#include "physics/body.h"
-
-
-#include <SDL2/SDL.h>
-
-#include <stdexcept>
/** Project namespace.
*
@@ -44,25 +39,21 @@
namespace yage
{
+extern void glfwErrorCallback(int, const char *);
+
/** Initializes yage.
*
* This is only there to initialize SDL2.
*
* @return Returns true if the initialization was successful.
*/
-bool init()
-{
- return SDL_Init(SDL_INIT_VIDEO);
-}
+extern void init();
/** Quit and cleanup yage
*
* SDL2 needs to clean itself up.
*/
-void quit()
-{
- SDL_Quit();
-}
+extern void quit();
} // namespace yage
@@ -44,25 +39,21 @@
/** Initializes yage.
*
- * This is only there to initialize SDL2.
+ * This is only there to initialize glfw.
*
* @return Returns true if the initialization was successful.
@@ -44,25 +39,21 @@
/** Quit and cleanup yage
*
- * SDL2 needs to clean itself up.
+ * glfw needs to clean itself up.
*/